# SEMANTIC PRIMING with high/low frequency targets presented in clear or dim font
# Masson & Kliegl: Experiment 2 (clear and dim trials presented blockwise in counterbalanced order)
# 15 June 2013, R. Kliegl

# PARTS of Script
# (1) Determination of "optimal" LMM (i.e., LMM m5) wrt var components and corr parameters
# (2) Two LMM m5 reparameterizations F x P nested within W by L 
# (3) Figures on the basis of LMM m5

# (4) Adding Trial as covariate to LMM m5 -> LMM x6, 
#     incl. various reparatmetrizations and alternative models
# (5) Figures for Trial x Lag-Target on the basis of LMM x6

# Additional analyses from June 2013
# (6) Check source of LagWord x Trial interaction (2 versions)

library(memisc)

library(lme4)
library(plyr)
library(ggplot2)

rm(list=ls())
source("functions/mtable-ext.R")  # requires package memisc
source("functions/remef.v0.6.7.R")

load("Exp2.rda")
# Dependent variables:  
# rt  is response time in ms
# rrt = -1000/rt  ; indicated by boxcox() (see Exp2.setup.R)


# PART 1: Determination of "optimal" LMM wrt significant variance components and correlation parameters


# Basic model with varying intercepts for subjects and stimuli
print(m1 <- lmer(rrt ~ 1 + W*Q*F*P + (1 | id) + (1 | st), data=d), cor=FALSE)

# Test variance components (no test of F = between-items)
print(m2 <- lmer(rrt ~ 1 + W*Q*F*P + (1 | id) + (1 | st) +
	              (0+W | id)  + (0+Q | id) + (0+F | id) + (0+P | id) +
	              (0+W | st)  + (0+Q | st)              + (0+P | st), data=d), cor=FALSE)

# ...  remaining variance components are highly significant if added by itself, except W.st (p =.09938), Q.st (p=.3794)
print(m2.Wid <- lmer(rrt ~ 1 + W*Q*F*P + (1 | id) + (1 | st) +
	       + (0+Q | id) + (0+F | id) + (0+P | id) + (0+W | st) + (0+Q | st) + (0+P | st), data=d), cor=FALSE)
anova(m2.Wid, m2) # Chi-sq(1) = 96, p < 2.2e-16

print(m2.Qid <- lmer(rrt ~ 1 + W*Q*F*P + (1 | id) + (1 | st) +
	       + (0+W | id) + (0+F | id) + (0+P | id) + (0+W | st) + (0+Q | st) + (0+P | st), data=d), cor=FALSE)
anova(m2.Qid, m2) # Chi-sq(1) = 229, p < 2.2e-16 

print(m2.Fid <- lmer(rrt ~ 1 + W*Q*F*P + (1 | id) + (1 | st) +
	       + (0+W | id) + (0+Q | id) + (0+P | id) + (0+W | st) + (0+Q | st) + (0+P | st), data=d), cor=FALSE)
anova(m2.Fid, m2) # Chi-sq(1) = 14, p = 0.0001615              
                                                               
print(m2.Pid <- lmer(rrt ~ 1 + W*Q*F*P + (1 | id) + (1 | st) + 
	       + (0+W | id) + (0+Q | id) + (0+F | id) + (0+W | st) + (0+Q | st) + (0+P | st), data=d), cor=FALSE)
anova(m2.Pid, m2) # Chi-sq(1) = 7, p =  0.008372              
                                                               
print(m2.Wst <- lmer(rrt ~ 1 + W*Q*F*P + (1 | id) + (1 | st) + 
	       + (0+W | id) + (0+Q | id) + (0+F | id) + (0+P | id) + (0+Q | st) + (0+P | st), data=d), cor=FALSE)
anova(m2.Wst, m2) # Chi-sq(1) = 2.71, p = 0.09983               

print(m2.Qst <- lmer(rrt ~ 1 + W*Q*F*P + (1 | id) + (1 | st) +
	       + (0+W | id) + (0+Q | id) + (0+F | id) + (0+P | id) + (0+W | st) + (0+P | st), data=d), cor=FALSE)
anova(m2.Qst, m2) # Chi-sq(1) = 0.7727, p = 0.3794                          
                                                                            
print(m2.Pst <- lmer(rrt ~ 1 + W*Q*F*P + (1 | id) + (1 | st) +              
	       + (0+W | id) + (0+Q | id) + (0+F | id) + (0+P | id) + (0+W | st) + (0+Q | st), data=d), cor=FALSE)
anova(m2.Pst, m2) # Chi-sq(1) =  8.1939, p = 0.004203

# ... test reduced model w/o W.st and Q.st
print(m3 <- lmer(rrt ~ 1 + W*Q*F*P + (1 | id) + (1 | st) +
	              (0+W | id) + (0+Q | id) + (0+F | id) + (0+P | id)  + (0+P | st), data=d), cor=FALSE)
anova(m2, m3)  # not significant, p = .1791

# ... all drop1 tests are significant--keep m3
print(m3.Pid <- lmer(rrt ~ 1 + W*Q*F*P + (1 | id) + (1 | st) +
	              (0+W | id) + (0+Q | id) + (0+F | id)  + (0+P | st), data=d), cor=FALSE)
anova(m3.Pid, m3) # Chi-sq(1) = 6.9, p = 0.00868

print(m3.Fid <- lmer(rrt ~ 1 + W*Q*F*P + (1 | id) + (1 | st) +
	              (0+W | id) + (0+Q | id) + (0+P | id)  + (0+P | st), data=d), cor=FALSE)
anova(m3.Fid, m3) # Chi-sq(1) = 14,  p = 0.0001801

print(m3.Qid <- lmer(rrt ~ 1 + W*Q*F*P + (1 | id) + (1 | st) +
	              (0+W | id) + (0+F | id) + (0+P | id)  + (0+P | st), data=d), cor=FALSE)
anova(m3.Qid, m3) # Chi-sq(1) = 229, p < 2.2e-16

print(m3.Wid <- lmer(rrt ~ 1 + W*Q*F*P + (1 | id) + (1 | st) +
	              (0+F | id) + (0+Q | id) + (0+P | id)  + (0+P | st), data=d), cor=FALSE)
anova(m3.Wid, m3) # Chi-sq(1) = 96, p < 2.2e-16

# ... test of ensemble of correlation parameters is significant (but not according to AIC and BIC)
print(m4 <- lmer(rrt ~ 1 + W*Q*F*P + (1+W+Q+F+P | id) + (1+P | st), data=d), cor=FALSE)
anova(m3, m4) 

# ... but only one correlation parameter is significant:  mean rt and priming effect: -0.507
print(m5 <- lmer(rrt ~ 1 + W*Q*F*P + (1 + P | id) + (1 | st) +
	               (0+W | id) + (0+Q | id) + (0+F | id)  + (0+P | st), data=d), cor=FALSE)
anova(m3, m4, m5) 
# LMM m5 is the declared the "optimal" LMM for this data (reported in Table 2, p. 909)

# Reproducing Table 2 with additional constraint of no-lag-1 error trials and with normal RTs
print(m5.lsc <- lmer(rrt ~ 1 + W*Q*F*P + (1 + P | id) + (1 | st) +
			   	(0+W | id) + (0+Q | id) + (0+F | id)  + (0+P | st), data=d.lsc), cor=FALSE)

print(m5.rt <- lmer(rt ~ 1 + W*Q*F*P + (1 + P | id) + (1 | st) +
			  	(0+W | id) + (0+Q | id) + (0+F | id)  + (0+P | st), data=d), cor=FALSE)

print(m5.rt.lsc <- lmer(rt ~ 1 + W*Q*F*P + (1 + P | id) + (1 | st) +
					(0+W | id) + (0+Q | id) + (0+F | id)  + (0+P | st), data=d.lsc), cor=FALSE)

mtable(m5, m5.lsc, m5.rt, m5.rt.lsc, coef.style="horizontal")

# Correlation parameters with rt as DV not really needed
print(m3.rt <- lmer(rt ~ 1 + W*Q*F*P + (1 | id) + (1 | st) +
		   (0+W | id) + (0+Q | id) + (0+F | id) + (0+P | id)  + (0+P | st), data=d), cor=FALSE)

print(m4.rt <- lmer(rt ~ 1 + W*Q*F*P + (1+W+Q+F+P | id) + (1+P | st), data=d), cor=FALSE)

print(m6.rt <- lmer(rt ~ 1 + W*Q*F*P + (1 + P | id) + (1 | st) +
			  	(0+W | id) + (0+Q | id) + (0+F | id)  + (0+P | st), data=d), cor=FALSE)

anova(m3.rt, m4.rt, m5.rt)


# PART 2:  Reparameterization: Q x F within W x P


# Version 1

# Which of the Q x F interactions within levels of W by P is significant? 
d$WPQF <- factor(paste(substr(d$w, 1, 1), substr(d$p, 1, 1), substr(d$q, 1, 1), substr(d$f, 1, 1), sep="_") ) 

# ... re-order alphabetically sorted levels to correspond to factorial design
d$WPQF <- factor(d$WPQF, levels = c(levels(d$WPQF)[9:16], levels(d$WPQF)[1:8]) ) 

# ... contrast matrix for 2 x 2 within 2 x 2 nested design
cmat   <- matrix(c(            -1/8, -1/8, -1/8, -1/8, -1/8, -1/8, -1/8, -1/8, +1/8, +1/8, +1/8, +1/8, +1/8, +1/8, +1/8, +1/8,
                               -1/8, -1/8, -1/8, -1/8, +1/8, +1/8, +1/8, +1/8, -1/8, -1/8, -1/8, -1/8, +1/8, +1/8, +1/8, +1/8,
                               +1/8, +1/8, +1/8, +1/8, -1/8, -1/8, -1/8, -1/8, -1/8, -1/8, -1/8, -1/8, +1/8, +1/8, +1/8, +1/8,
                               -1/2, -1/2, +1/2, +1/2,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
                               -1/2, +1/2, -1/2, +1/2,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
                               +1/2, -1/2, -1/2, +1/2,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
                                  0,    0,    0,    0, -1/2, -1/2, +1/2, +1/2,    0,    0,    0,    0,    0,    0,    0,    0,
                                  0,    0,    0,    0, -1/2, +1/2, -1/2, +1/2,    0,    0,    0,    0,    0,    0,    0,    0,
                                  0,    0,    0,    0, +1/2, -1/2, -1/2, +1/2,    0,    0,    0,    0,    0,    0,    0,    0,
                                  0,    0,    0,    0,    0,    0,    0,    0, -1/2, -1/2, +1/2, +1/2,    0,    0,    0,    0,
                                  0,    0,    0,    0,    0,    0,    0,    0, -1/2, +1/2, -1/2, +1/2,    0,    0,    0,    0,
                                  0,    0,    0,    0,    0,    0,    0,    0, +1/2, -1/2, -1/2, +1/2,    0,    0,    0,    0,
                                  0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0, -1/2, -1/2, +1/2, +1/2,
                                  0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0, -1/2, +1/2, -1/2, +1/2,
                                  0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0, +1/2, -1/2, -1/2, +1/2 ), 16, 15)

cmat.i <- fractions(t(ginv(cmat)))
rownames(cmat.i) <- levels(d$WPQF)
colnames(cmat.i) <- c(".lW", ".P", ".lW_P", ".q1", ".f1", ".qf1", ".q2", ".f2", ".qf2", ".q3", ".f3", ".qf3",  ".q4", ".f4", ".qf4" )
(contrasts(d$WPQF) <- cmat.i)

print(m5a <- lmer(rrt ~ 1 + WPQF + (1 + P | id) + (1 | st) +
	               (0+W | id) + (0+Q | id) + (0+F | id)  + (0+P | st), data=d), cor=FALSE)

# ... check logLik
anova(m5, m5a)

# Version 2

# Merging the diagonal  Q x F interactions within levels of W by P
# ... contrast matrix for 2 x 2 within 2 x 2 nested design
cmat2   <- matrix(c(           -1/8, -1/8, -1/8, -1/8, -1/8, -1/8, -1/8, -1/8, +1/8, +1/8, +1/8, +1/8, +1/8, +1/8, +1/8, +1/8,
                               -1/8, -1/8, -1/8, -1/8, +1/8, +1/8, +1/8, +1/8, -1/8, -1/8, -1/8, -1/8, +1/8, +1/8, +1/8, +1/8,
                               +1/8, +1/8, +1/8, +1/8, -1/8, -1/8, -1/8, -1/8, -1/8, -1/8, -1/8, -1/8, +1/8, +1/8, +1/8, +1/8,
                               -1/4, -1/4, +1/4, +1/4,    0,    0,    0,    0,    0,    0,    0,    0, -1/4, -1/4, +1/4, +1/4,
                               -1/4, +1/4, -1/4, +1/4,    0,    0,    0,    0,    0,    0,    0,    0, -1/4, +1/4, -1/4, +1/4,
                               +1/4, -1/4, -1/4, +1/4,    0,    0,    0,    0,    0,    0,    0,    0, +1/4, -1/4, -1/4, +1/4, 
                                  0,    0,    0,    0, -1/4, -1/4, +1/4, +1/4,  -1/4, -1/4, +1/4, +1/4,    0,    0,    0,    0,
                                  0,    0,    0,    0, -1/4, +1/4, -1/4, +1/4,  -1/4, +1/4, -1/4, +1/4,    0,    0,    0,    0,
                                  0,    0,    0,    0, +1/4, -1/4, -1/4, +1/4,  +1/4, -1/4, -1/4, +1/4,    0,    0,    0,    0), 16, 9)

cmat2.i <- fractions(t(ginv(cmat2)))
rownames(cmat2.i) <- levels(d$WPQF)
colnames(cmat2.i) <- c(".lW", ".P", ".lW_P", ".q5", ".f5", ".qf5", ".q6", ".f6", ".qf6" )
(contrasts(d$WPQF) <- cmat2.i)

print(m5b <- lmer(rrt ~ 1 + WPQF + (1 + P | id) + (1 | st) +
	               (0+W | id) + (0+Q | id) + (0+F | id)  + (0+P | st), data=d), cor=FALSE)

# ... check logLik
anova(m5, m5b)


# PART 3: Figures for LMM m5


# Copy and relevel factors for plots
d <- transform(d, 
		   Lag_Target = factor(w, levels=c("W", "NW"), labels= c("N-1: Word", "N-1: Nonword")),
		   Lag_Target2 = factor(w, levels=c("NW", "W"), labels= c("N-1: Nonword", "N-1: Word")),
		   Frequency = factor(f, levels=c("LF", "HF"), labels=c("Low", "High")),
		   Priming = factor(p, levels=c("Rel", "Unr"), labels=c("Related", "Unelated")),
		   Priming2 = factor(p, levels=c("Unr", "Rel"), labels=c("Unrelated", "Related")),
		   Quality = factor(q, levels=c("Degraded", "Clear"))) 

# Figure 7. Frequency x Priming x Quality (p. 908), based on regular ANOVA of RTs for subjects
# ... F1-ANOVA
d_subj <- ddply(d, .(id, Frequency, Priming2, Quality), summarise, RT=mean(rt) )
summary(aov(RT ~ Frequency*Priming2*Quality + Error(id/(Frequency*Priming2*Quality)), data=d_subj))

# ... Table of means and within-subject SEs 
#     (Loftus & Masson, 1994; Cousineau, 2005; Morey, 2008)
# ... ... grand mean of RT
GM <- mean(d_subj$RT)

# ... ... remove between-subject variance; C = Cousineau (2005)
d_subj <- ddply(d_subj, .(id), transform, RT_C = RT - mean(RT) + GM)

Table.fig7 <- ddply(d_subj, .(Frequency, Priming2, Quality), summarise, 
			  N=length(RT), M=mean(RT), SD=sd(RT), 
			  SE_C=sd(RT_C)/sqrt(N), CI_C=SE_C*qt(.975, N-1) )

# ... ... adjust SEs for number of measures; M = Morey (2008), mf=Moray factor
nl <- nlevels(d_subj$Frequency)*nlevels(d_subj$Priming2)*nlevels(d_subj$Quality) 
mf <- sqrt( nl/(nl-1) )  

Table.fig7$SE_M <- Table.fig7$SE_C*mf
Table.fig7$CI_M <- Table.fig7$SE_M*qt(.975, Table.fig7$N-1)

# ... generate figure 
(Plot.fpq <- ggplot(data=Table.fig7, aes(x=Frequency, y=M, group=Quality:Priming2)) +
	xlab("Word Frequency") + ylab("Response Time [ms]") + 
 	geom_errorbar( aes(ymax=M+2*SE_M, ymin=M-2*SE_M, width=0.03) ) +
 	geom_line(aes(linetype=Quality:Priming2)) +
	geom_point(aes(shape=Quality:Priming2), size=3, fill = "white") + 			 
 	scale_linetype_manual("Priming", values=c(2, 2, 1, 1)) +
 	scale_shape_manual("Priming", values=c(19, 21, 19, 21) ) +
 	theme_bw() + theme(legend.title=element_blank()) + 
 	theme(legend.justification=c(1, 1), legend.position=c(1, 1)))  

# Alternative for Morey-based within-subject SEs and CIs (from Winston Chang)
# source("functions/normDataWithin.R")
# source("functions/summarySE.R")
# source("functions/summarySEwithin.R")
# summarySEwithin(data=d_subj, idvar="id", measurevar="RT", withinvars=c("f", "p", "q"))

# Figure 8
d$wpqf <- remef(m5, keep=TRUE, grouping=TRUE, fix = c(1, "W:Q:F:P"), ran = NULL) 

# ... Ms and SEs
Table.fig8 <- ddply(d, .(Lag_Target, Priming, Quality, Frequency), summarise, N=length(wpqf), M=mean(wpqf), SE=sd(wpqf)/sqrt(N) )

# ... generate figure 
(Plot.wpqf <- ggplot(data=Table.fig8, aes(x=Frequency, y=M, group=Quality)) +
	ylab("Response Time [-1/RT]") +
 	facet_grid(Priming ~ Lag_Target)  + 
 	geom_errorbar(aes(ymax=M+2*SE, ymin=M-2*SE, width=0.03) ) +
 	geom_line() + geom_point(aes(shape=Quality), size=3, fill = "white") +
 	scale_shape_manual("Quality", values=c(21, 19) ) + theme_bw() )


# -----------------------------------------------


# PART 4: LMM m5 plus trial as covariate = LMM x6 

# LMM x6 (and variations)
print(x6  <- lmer(rrt ~ 1 + W*Q*F*P + poly(trial.c, 2) + W:trial.c +
				(1+P | id) + (0+W | id) + (0+Q | id) + (0+F | id) + (1 | st) + (0+P | st), data=d, REML=TRUE), cor=FALSE)

# Reparametrization of trial effects within panels of last Target, 
# ... that is separate estimates for trial for lag-word and lag-nonword targets,
# but main effect of quadratic trend for trial
d$lW_trial <- ifelse(d$W==-0.5, d$trial.c, 0)
d$lNW_trial <- ifelse(d$W==+0.5, d$trial.c, 0)

print(x6a <- lmer(rrt ~ 1 +  W*Q*F*P + lW_trial + lNW_trial + poly(trial.c, 2)[ ,2] +
				(1+P | id) + (0+W | id) + (0+Q | id) + (0+F | id) + (1 | st) + (0+P | st), data=d, REML=TRUE), cor=FALSE)

anova(x6, x6a) 

# To see linear trends within levels, leave out quadratic term
print(x6b <- lmer(rrt ~ 1 +  W*Q*F*P + lW_trial + lNW_trial  +
				(1+P | id) + (0+W | id) + (0+Q | id) + (0+F | id) + (1 | st) + (0+P | st), data=d, REML=TRUE), cor=FALSE)

anova(x6b, x6a, x6) 

# Using only correctly answered lag trials and using untransformed RT as DV
print(x6.lsc  <- lmer(rrt ~ 1 + W*Q*F*P + poly(trial.c, 2) + W:trial.c +
			    	(1+P | id) + (0+W | id) + (0+Q | id) + (0+F | id) + (1 | st) + (0+P | st), data=d.lsc, REML=TRUE), cor=FALSE)

print(x6.rt  <- lmer(rt ~ 1 + W*Q*F*P + poly(trial.c, 2) + W:trial.c +
			   	(1+P | id) + (0+W | id) + (0+Q | id) + (0+F | id) + (1 | st) + (0+P | st), data=d, REML=TRUE), cor=FALSE)

print(x6.rt.lsc  <- lmer(rt ~ 1 + W*Q*F*P + poly(trial.c, 2) + W:trial.c +
				 	(1+P | id) + (0+W | id) + (0+Q | id) + (0+F | id) + (1 | st) + (0+P | st), data=d.lsc, REML=TRUE), cor=FALSE)

mtable(x6, x6.lsc, x6.rt, x6.rt.lsc, coef.style="horizontal")

# Compare residuals for LMM m5 and LMM x6
qqmath(resid(m5))
qqmath(resid(x6))

resdf.m5 <- data.frame(model="m5", x=fitted(m5), y=resid(m5))
resdf.x6 <- data.frame(model="x6", x=fitted(x6), y=resid(x6))
resdf <- rbind(resdf.m5, resdf.x6)
qplot(data=resdf, x=x, y=y, geom="point", shape=I("."), facets=. ~ model,	
	xlab="Fitted values", ylab="Standardized residuals") + 
	geom_hline(yintercept=0) + theme_bw() + 
	geom_density2d(size=1) 
#     geom_hex() + geom_density2d(size=0.2, col="white")


# PART 5: Figures based on LMM x6


# Figure 9: Trial x Lag Target (Word vs. Nonword)
d$wt  <- remef(x6, keep=TRUE, 
		   fix = c(1, "W", "poly(trial.c, 2)1",  "poly(trial.c, 2)1", "W:trial.c"), ran = NULL)

# ... partial effects in transformed rt (i.e., -1000/rt)
(wt <- ggplot(d, aes(x=trial, y=wt) ) + xlab("Trial") + 
 	geom_smooth( aes(group = Lag_Target2, colour=Lag_Target2), method="lm", formula=y~poly(x, 2), size=1) +
 	scale_colour_manual("N-1 Target", values=c("red", "blue")) +
 	scale_y_continuous("Response Time  [-1/s]", breaks=seq(from=-1.80, to=-1.50, by=.05)) +  
 	coord_cartesian(ylim=c(-1.80, -1.50) ) ) + theme_bw()

# ... observed untransformed RT
(ggplot(d, aes(x=trial, y=rt) ) + xlab("Trial") + 
 	geom_smooth( aes(group = Lag_Target2, colour=Lag_Target2), method="lm", formula=y~poly(x, 2), size=1) +
 	scale_colour_manual("N-1 Target", values=c("red", "blue")) +
 	scale_y_continuous("Response Time [ms]", breaks=seq(from=500, to=700, by=20)) +  
 	coord_cartesian(ylim=c(550, 650) ) + theme_bw() )

# PART 7

# Added 21 June 2013, 
# Test Mike's proposal to look whether trial x type of last target (W vs. NW) is also
# significant for unrelated vs. related last type of target trials (all of which were word trials)
table(d$lpr, d$w)
table(d$ltt, d$w)

# Version 1: Select on trials where last trial was also a word target
d2 <- droplevels(subset(d, w == "W"))  # pt = prev
table(d2$lpr, d2$w)

d2$LPR <- ifelse(d2$lpr == "Rel",  -1/2, +1/2)

print(x7  <- lmer(rrt ~ 1 + LPR+Q*F*P*trial.c + LPR:trial.c +
				(1+P | id) + (0+trial.c | id) + (0+Q | id) + (0+F | id) + (1 | st) + (0+P | st) + (0+trial.c | st), data=d2, REML=TRUE), cor=FALSE)

print(x7a  <- lmer(rrt ~ 1 + LPR+Q*F*P + trial.c + LPR:trial +
			 	(1+P | id) + (0+Q | id) + (0+trial.c | id) + (0+F | id) + (1 | st) + (0+P | st) + (0+trial.c | st), data=d2, REML=TRUE), cor=FALSE)

print(x7b  <- lmer(rrt ~ 1 + LPR+Q*F*P + trial.c + LPR:trial.c
			 (1+P | id) + (0+Q | id) + (0+trial.c | id) + (0+F | id) + (1 | st) + (0+P | st), data=d2, REML=TRUE), cor=FALSE)
anova(x7b, x7a, x7) # marginally significant between-item variance in trial.c!


print(x7c  <- lmer(rrt ~ 1 + LPR+Q*F*P + trial.c + LPR:trial.c +
			 	(1+P | id) + (0+Q | id)  + (0+F | id) + (1 | st) + (0+P | st) + (0+trial.c | st),, data=d2, REML=TRUE), cor=FALSE)
anova(x7b, x7a, x7) # significant between-subject variance in trial.c!

d2$xt  <- remef(x7a, keep=TRUE, grouping=TRUE,
		    fix = c(1, "P", "trial.c", "LPR:trial.c"), ran = NULL)

# ... partial effects in transformed rt (i.e., -1000/rt)
(Plot.xt <- ggplot(d, aes(x=trial, y=xt) ) + xlab("Trial") + 
 	geom_smooth( aes(group = lpr, colour=lpr), method="lm", formula=y~poly(x, 2), size=1) +
 	scale_colour_manual("N-1 Target", values=c("red", "blue")) +
 	scale_y_continuous("Response Time  [-1/s]", breaks=seq(from=-1.80, to=-1.50, by=.05)) +  
 	coord_cartesian(ylim=c(-1.70, -1.60) ) ) + theme_bw()

d2$p_lpr  <- remef(x7, keep=TRUE, grouping=TRUE, fix = c(1, "LPR:P", ran = NULL))
Table.lpr_p <- ddply(d2, .(p, lpr), summarise, N=length(p_lpr), M=mean(p_lpr), SD=sd(p_lpr), SE=SD/sqrt(N))


# ... generate figure 
(Plot.lpr_p <- ggplot(data=Table.lpr_p, aes(x=p, y=M, group=lpr)) +
 	geom_errorbar( aes(ymax=M+2*SE, ymin=M-2*SE, width=0.03) ) +
 	geom_line() + geom_point(aes(shape=lpr), size=3, fill = "white") + 
 	scale_y_continuous("Response Time  [-1/s]", breaks=seq(from=-1.80, to=-1.50, by=.05)) +  
 	scale_shape_manual("LastRelation", values=c(21, 19) ) +
 	coord_cartesian(ylim=c(-1.80, -1.50) ) + theme_bw() +
 	theme(legend.justification=c(1, 1), legend.position=c(1, 1)))

# Version 2: Respecify factor w as lt (last target type) with 3 levels/2 contrasts: LP = unrW -relW; LW = unrNW - unrW
d$lt <- ifelse(d$w == "NW", "UnrNW",  ifelse(d$lpr == "Rel", "RelW", "UnrW"))
d$lt <- factor(d$lt, levels=c("RelW", "UnrW", "UnrNW"))
table(d$lt, d$w)

contrasts(d$lt) <- MASS::contr.sdif(3)
d$LP <- ifelse(d$lt == "RelW", -2/3, 1/3)
d$LW <- ifelse(d$lt == "UnrNW", 2/3, -1/3)

print(x8  <- lmer(rrt ~ 1 + (LP + LW)*Q*F*P*trial.c + (LP + LW):trial.c +
				+ 				(1+P | id) + (0+trial.c | id) + (0+Q | id) + (0+F | id) + (1 | st) + (0+P | st) + (0+trial.c | st), data=d, REML=TRUE), cor=FALSE)	

# ... observed effect in transformed rt (i.e., -1000/rt)
(Plot.rrt <- ggplot(d, aes(x=trial, y=rrt) ) + xlab("Trial") + 
 	geom_smooth( aes(group = lt, colour=lt), method="lm", formula=y~poly(x, 2), size=1) +
 	scale_colour_manual("N-1 Target", values=c("red", "blue", "black")) +
 	scale_y_continuous("Response Time  [-1/s]", breaks=seq(from=-1.85, to=-1.65, by=.05)) +  
 	coord_cartesian(ylim=c(-1.85, -1.65) ) ) + theme_bw()
